/*
 * An LED strip gauge for the light sensor and sound sensor. One 
 *  reading displays from each end towards the middle of the strip.
 */

//Include the LED_Strip library to use the commands
//Don't have the library? Visit http://letsstartcoding.com/libraries
#include "LEDStrip.h"

const byte numPixels = 15; //number of pixels on a strip

//Make an LED strip object: LEDStrip(numPixels,dataPin(DI),clockPin(CI))
LEDStrip strip = LEDStrip(numPixels, 13, 12);

void setup() {
  pinMode(A4,INPUT);//Center pin of sound trigger

  pinMode(A2,INPUT_PULLUP); //Light sensor
}

void loop() {
  //Limits for the sound sensor, change these for your environment
  const int soundMin = 400;
  const int soundMax = 800;

  //Map the light values of 50 to 950 onto lower half of LED strip
  const int lightValue = map(analogRead(A2),50,950,0,numPixels/2);

  //Map the soundValues onto upper half of LED strip
  int soundValue = map(analogRead(A4),soundMin,soundMax,
                      numPixels,(numPixels/2));
 
  //Constrain soundPixel's values to the upper half of the strip
  soundValue = constrain(soundValue,(numPixels/2),numPixels);

  //Starting at bottom, count up to lightPixel and set those pixels
  for (int i = 0; i < lightValue; i++){
    strip.setPixel(i, 50); //50 is purple (colors are 0-300)
  }

  //Starting at tip of strip, count down to soundPixel and set pixels
  for (int i = numPixels; i > soundValue; i--){
    strip.setPixel(i, 100); //100 is red (colors are 0-300)
   }

  //Starting at the top of lightPixel, count up to soundPixel and clear
  //the pixels in the middle of the strip.
  for(int i = lightValue; i < soundValue; i++){
    strip.setPixel(i,-1); //-1 is clear (no color)
  }
  strip.draw(); //send all of the .setPixel() commands to the strip
}

//Change the color arguments in the setPixel commands to make the 
//  colors change with the value of soundPixel and lightPixel

//Hint: add some multiple of lightPixel and soundPixel as the color values

//Need help? http://www.letsstartcoding.com/help

//(c) 2015 Let's Start Coding. License: www.letsstartcoding.com/bsdlicense/
