/*
 * An LED strip gauge for the sound sensor. The louder it is, the 
 *  more pixels will be illuminated.
 */
 
//Include the LEDStrip library to use the commands
//Don't have the library? Visit http://letsstartcoding.com/libraries
#include "LEDStrip.h"

const byte numPixels = 15; //number of pixels on a strip

//Make an LED strip object: LEDStrip(numPixels,dataPin(DO),clockPin(CO))
LEDStrip strip = LEDStrip(numPixels, 13, 12);

//The average noise level
float averageNoise;


void setup() {
  pinMode(A4,INPUT); //Center pin of sound trigger

  //Get initial sound measurement to 'seed' the average
  averageNoise = analogRead(A4);
}

void loop() {

  //Compute the moving average of the noise level
  //Each new reading contributes 50% to the average
  averageNoise = 0.5*(float)(analogRead(A4)) + 0.5*(averageNoise);
  //soundValue is cast to a float so it can be multiplied by decimals
 
  strip.clear(); //Make the strip blank after every reading

  //Map the sound values of 300 to 450 onto the LED strip
  const byte pixel = map(int(averageNoise),300,450,0,numPixels);

  //Pixel will have a value between 0 and numPixels
  //Turn on each pixel up to that number
  for (int i = 0; i < pixel;i++){
    strip.setPixel(i, 10); //Colors range 0-300, 10 is blue
  }

  strip.draw(); //Tell the strip to display the .setPixel commands
}

//Re-map noise level (300-450) to color (0-300), and display on all
//  LEDs with the strip.ALL in place of 'pixel' in setPixel

//Hint: Replace the for loop and pixel map with one line of setPixel

// Need help? http://www.letsstartcoding.com/help

// (c) 2015 Let's Start Coding. License: www.letsstartcoding.com/bsdlicense

