/*
 * An LED strip gauge for the temperature sensor. The warmer it is,
 *  the more pixels are illuminated.
 */

//Include the LEDStrip library to use the commands
//Don't have the library? Visit http://letsstartcoding.com/libraries
#include "LEDStrip.h"

const byte numPixels = 15; //number of pixels on a strip

//Make an LED strip object: LEDStrip(numPixels,dataPin(DO),clockPin(CO))
LEDStrip strip = LEDStrip(numPixels, 13, 12);

//Take a reading to seed the average value
float tempAverage = analogRead(A4);

void setup() {
  //Check the temp sensor pinout, getting it backwards ruins it
  pinMode(A4,INPUT); //Center pin of temp sensor
  //One of the outside pins is in 5V, the other is in GND row
}

void loop() {
  
  //Take a new temperature reading each loop and add it to the average
  //Each new reading contributes 10% to the average
  tempAverage = 0.9*tempAverage + 0.1*float(analogRead(A4));
  //tempRead is cast to a float so it can be multiplied by decimals
  
  //Converting reading to F with conversion equation
  const int tempF = int(0.88*float(tempAverage) - 58.0);

  strip.clear(); //Clear the strip

  //Map the temp values of 60 to 80 onto the LED strip
  const int pixel = map(tempF,60,80,0,numPixels);

  //Pixel will have a value between 0 and numPixels
  //Turn on each pixel up to that number
  for (int i = 0; i < pixel;i++){
    strip.setPixel(i, 200); //colors range from 0-300. 200 is green
  }
  
  strip.draw(); //Draw the pixels
}

//Remap temperature (60-80) to color (300-0), and display on all
//  LEDs with the strip.ALL in place of 'pixel' in setPixel

//Hint: Replace the for loop and pixel map with one line of setPixel

// (c) 2015 Let's Start Coding. License: www.letsstartcoding.com/bsdlicense

