/*
 * Use the temp sensor, sound trigger, and light sensor to indicate
 *  quality of a nap spot
 */

//Hold the average noise level
float averageNoise;

//Timer to control the display
long timer = millis();

void setup() {

  pinMode(A4,INPUT);      //Center pin of sound trigger

  pinMode(A2,INPUT_PULLUP); //light sensor
  
  //Check the temp sensor pinout, getting it backwards ruins it
  pinMode(A3,INPUT); //Center pin of temp sensor
  //One of the outside pins is in 5V, the other is in GND row
    
  //LEDs
  pinMode(9,OUTPUT);
  pinMode(10,OUTPUT);
  pinMode(11,OUTPUT);


  //Get initial sound measurement to 'seed' the average
  averageNoise = analogRead(A4);
}

void loop() {
    
  //Compute the moving average of the noise level
  //Each new reading contributes 1% to the average
  averageNoise = 0.01*(float)(analogRead(A4)) + 0.99*(averageNoise);
  //soundValue is cast to a float so it can be multiplied by decimals

  /* Because the microphone needs to be read very often,
   *  use millis to print only once every 500 ms*/
  if (millis()-timer > 500){
    
    //Converting reading to F with conversion equation
    int tempF = int(0.88*float(analogRead(A3)) - 58.0);

    //Read the light sensor
    int lightValue = analogRead(A2);

    //When it's cold, LED is off
    if (tempF < 68){
      analogWrite(9,0);} //LED off
    else if (tempF < 75){
      analogWrite(9,127);} //Half brightness
    else{
      analogWrite(9,255);} //Full brightness
      

    //When it's dark, LED is at full brightness
    if (lightValue < 300){
      analogWrite(11,0);} //LED off
    else if (lightValue < 600){
      analogWrite(11,127);} //Half brightness
    else{
      analogWrite(11,255);} //Full brightness

    
    //When it's quiet, LED is at full brightness
    if (averageNoise < 350){
      analogWrite(10,255);} //Full brightness
    else if (averageNoise < 500){
      analogWrite(10,127);} //Half brightness
    else{
      analogWrite(10,0);} //LED off
      
    timer = millis(); //Reset the timer
  }
}

//Change the analogWrites so that blue/green indicates a good spot
//  and red indicates a bad spot

// Need help? http://www.letsstartcoding.com/help

// (c) 2016 Let's Start Coding. License: www.letsstartcoding.com/bsdlicense

