/*
 * Display the mood of your room by taking light, sound, and
 * temperature readings.
 */

float averageNoise;//hold the average of all the noise readings

//Using a timer variable and millis() gets rid of delay
long timer = millis();

void setup() {
  pinMode(A4,INPUT);      //Center pin of sound trigger

  pinMode(A2,INPUT_PULLUP); //Light sensor
  
  //Check the temp sensor pinout, getting it backwards ruins it
  pinMode(A3,INPUT); //Center pin of temp sensor
  //One of the outside pins is in 5V, the other is in GND row

  //Get initial sound measurement to 'seed' the average
  averageNoise = analogRead(A4);

  //LED pins or a single multicolor LED
  pinMode(9,OUTPUT);
  pinMode(10,OUTPUT);
  pinMode(11,OUTPUT);
}

void loop() {
  //Compute the moving average of the noise level
  //Each new reading contributes 1% to the average
  averageNoise = 0.3*((float)(analogRead(A4))) + 0.7*(averageNoise);
  //soundValue is cast to a float so it can be multiplied by decimals
  
  /* Because the microphone needs to be read very often,
   *  use millis to print only once every 250 ms*/
  if (millis()-timer > 250){ //this loop runs every 250 milliseconds

    //converting reading to tempF with conversion equation
    const int tempF = int(0.88*float(analogRead(A3)) - 58.0);

    //Read the light sensor
    const int lightValue = analogRead(A2);

    //Map temp of 60-80 F to LED brightness of 0-255 
    analogWrite(10, map(tempF,60,80,0,255));
    
    //Map light reading of 50-1000 to LED brightness of 0-255
    analogWrite(9,map(lightValue,50,1000,0,255));

    //Map sound reading of 200-800 to LED brightness of 0-255
    analogWrite(11,map((int)(averageNoise),200,800,0,255));

    timer = millis(); //Reset the timer to millis so difference is 0
  }
}

//Change the map range for the light sensor (100-900) to make the
//  LED get brighter as the light level decreases

//Need help? http://www.letsstartcoding.com/help

// (c) 2016 Let's Start Coding. License: www.letsstartcoding.com/bsdlicense

